CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
108 lines
4.0 KiB
C++
108 lines
4.0 KiB
C++
/*
|
|
Copyright (c) 2025 Advanced Micro Devices, Inc. All rights reserved.
|
|
Permission is hereby granted, free of charge, to any person obtaining a copy
|
|
of this software and associated documentation files (the "Software"), to deal
|
|
in the Software without restriction, including without limitation the rights
|
|
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
|
copies of the Software, and to permit persons to whom the Software is
|
|
furnished to do so, subject to the following conditions:
|
|
The above copyright notice and this permission notice shall be included in
|
|
all copies or substantial portions of the Software.
|
|
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
|
|
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
|
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
|
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
|
|
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
|
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
|
THE SOFTWARE.
|
|
*/
|
|
/*
|
|
Testcase Scenarios :
|
|
|
|
*/
|
|
#include "occupancy_common.hh"
|
|
#include "distributed_shared_memory.hh"
|
|
#include "resource_guards.hh"
|
|
|
|
static __global__ void f1(float* a) { *a = 1.0; }
|
|
static void host_f1(float* a) { *a = 1.0; }
|
|
static __global__ void reverse(int* d, int n) {
|
|
__shared__ int shBuf[64];
|
|
int t = threadIdx.x;
|
|
int tr = n - t - 1;
|
|
|
|
shBuf[t] = d[t];
|
|
__syncthreads();
|
|
d[t] = shBuf[tr];
|
|
};
|
|
|
|
TEST_CASE("Unit_hipOccupancyMaxPotentialClusterSize_Positive_RangeValidation") {
|
|
int clusterSize;
|
|
hipDeviceProp_t props;
|
|
hipLaunchConfig_t config = {};
|
|
|
|
config.blockDim = {1024};
|
|
HIP_CHECK(hipGetDeviceProperties(&props, 0));
|
|
|
|
if (!props.clusterLaunch) {
|
|
HIP_SKIP_TEST("cluster launches are not supported on this device");
|
|
}
|
|
|
|
HIP_CHECK(
|
|
hipOccupancyMaxPotentialClusterSize(&clusterSize, reinterpret_cast<const void*>(f1), &config));
|
|
INFO("Max potential cluster size is: " << clusterSize);
|
|
// at the time of this writing a SPI could be drive up to 15 CUs. The number of CUs per SE
|
|
// varies per silicon, but any AMD silicon should have at least 8
|
|
REQUIRE((clusterSize > 8 && clusterSize <= 16));
|
|
}
|
|
|
|
TEST_CASE("Unit_hipOccupancyMaxPotentialClusterSize_Negative_Parameters") {
|
|
hipLaunchConfig_t config = {};
|
|
hipError_t hip_error;
|
|
int clusterSize = -1;
|
|
hipDeviceProp_t props;
|
|
hipLaunchAttribute attribute[1];
|
|
|
|
config.blockDim = {1024};
|
|
attribute[0].id = hipLaunchAttributeClusterDimension;
|
|
attribute[0].val.clusterDim.x = 1;
|
|
attribute[0].val.clusterDim.y = 1;
|
|
attribute[0].val.clusterDim.z = 1;
|
|
config.numAttrs = 1;
|
|
config.attrs = attribute;
|
|
HIP_CHECK(hipGetDeviceProperties(&props, 0));
|
|
|
|
if (!props.clusterLaunch) {
|
|
SUCCEED("cluster launches are not supported on this device");
|
|
return;
|
|
}
|
|
|
|
SECTION("block too big") {
|
|
config.blockDim = std::numeric_limits<unsigned int>::max();
|
|
hip_error = hipOccupancyMaxPotentialClusterSize(&clusterSize, reinterpret_cast<const void*>(f1),
|
|
&config);
|
|
REQUIRE(hip_error == hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("invalid function pointer") {
|
|
hip_error = hipOccupancyMaxPotentialClusterSize(
|
|
&clusterSize, reinterpret_cast<const void*>(host_f1), &config);
|
|
REQUIRE(hip_error == hipErrorInvalidDeviceFunction);
|
|
}
|
|
|
|
SECTION("not enough shared memory") {
|
|
config.dynamicSmemBytes = props.sharedMemPerBlock + 1;
|
|
HIP_CHECK(hipOccupancyMaxPotentialClusterSize(&clusterSize, reinterpret_cast<const void*>(f1),
|
|
&config));
|
|
REQUIRE(clusterSize == 0);
|
|
}
|
|
|
|
SECTION("not enough shared memory 2") {
|
|
config.dynamicSmemBytes = props.sharedMemPerBlock;
|
|
HIP_CHECK(hipOccupancyMaxActiveClusters(&clusterSize, reinterpret_cast<const void*>(reverse),
|
|
&config));
|
|
// reverse() uses a bit of (non-dynamic) shared memory; enough to go over the limit
|
|
REQUIRE(clusterSize == 0);
|
|
}
|
|
}
|